@@ -148,6 +148,25 @@ def djfrontend_jquery_formset(v):
             return '<script src="%sdjfrontend/js/jquery/jquery.formset/%s/jquery.formset.min.js"></script>' % (settings.STATIC_URL, v)
 
 
+@register.simple_tag
+def djfrontend_jquery_scrollto(v):
+    """ Returns the jQuery ScrollTo plugin file according to version number.
+    TEMPLATE_DEBUG returns full file, otherwise returns minified file.
+    """
+    if getattr(settings, 'TEMPLATE_DEBUG',):
+        return '<script src="%sdjfrontend/js/jquery/jquery.scrollTo/%s/jquery.scrollTo.js"></script>' % (settings.STATIC_URL, v)
+    else:
+        if hasattr(settings, 'DJFRONTEND_STATIC_URL'):
+            output=[
+                '<script src="%sdjfrontend/js/jquery/jquery.scrollTo/%s/jquery.scrollTo.min.js"></script>' % (settings.DJFRONTEND_STATIC_URL, v)
+            ]
+        else:
+            output=[
+                '<script src="%sdjfrontend/js/jquery/jquery.scrollTo/%s/jquery.scrollTo.min.js"></script>' % (settings.STATIC_URL, v)
+            ]
+        return '\n'.join(output)
+
+
 @register.simple_tag
 def djfrontend_jquery_smoothscroll(v):
     """ Returns the jQuery Smooth Scroll plugin file according to version number.
@@ -182,13 +201,16 @@ def djfrontend_twbs_css(v):
 
 
 @register.simple_tag
-def djfrontend_twbs_glyphicons(v):
-    """ Returns Twitter Bootstrap Glyphicons CSS file.
+def djfrontend_twbs_theme_css(v):
+    """ Returns Twitter Bootstrap Theme CSS file.
     """
-    if hasattr(settings, 'DJFRONTEND_STATIC_URL'):
-        return '<link rel="stylesheet" href="%sdjfrontend/css/twbs/%s/bootstrap-glyphicons.css">' % (settings.DJFRONTEND_STATIC_URL, v)
+    if getattr(settings, 'TEMPLATE_DEBUG',):
+        return '<link rel="stylesheet" href="%sdjfrontend/css/twbs/%s/bootstrap-theme.css">' % (settings.STATIC_URL, v)
     else:
-        return '<link rel="stylesheet" href="%sdjfrontend/css/twbs/%s/bootstrap-glyphicons.css">' % (settings.STATIC_URL, v)
+        if hasattr(settings, 'DJFRONTEND_STATIC_URL'):
+            return '<link rel="stylesheet" href="%sdjfrontend/css/twbs/%s/bootstrap-theme.min.css">' % (settings.DJFRONTEND_STATIC_URL, v)
+        else:
+            return '<link rel="stylesheet" href="%sdjfrontend/css/twbs/%s/bootstrap-theme.min.css">' % (settings.STATIC_URL, v)
 
 
 @register.tag(name='djfrontend_twbs_js')
